@@ -56,7 +56,7 @@ def default(obj: Any, default_: object = "", *, allow_false: bool = False) -> An
     if allow_false is True and _obj is False:
         return obj
 
-    if is_undefined(_obj) or _obj in (None, False, EMPTY):
+    if _obj in (None, False, EMPTY):
         return default_
 
     return obj
